Learn R Programming

laminr (version 0.4.1)

connect: Connect to instance

Description

Note that prior to connecting to an instance, you need to authenticate with lamin login. If no slug is provided, the default instance is loaded, which is set by running lamin connect <slug>.

Usage

connect(slug = NULL)

Arguments

slug

The instance slug account_handle/instance_name or URL. If the instance is owned by you, it suffices to pass the instance name. If no slug is provided, the default instance is loaded.

Examples

Run this code
if (FALSE) {
# first run 'lamin login' to authenticate
instance <- connect("laminlabs/cellxgene")
instance
}

Run the code above in your browser using DataLab