laminr_status: laminr status

View source: R/status.R

laminr_statusR Documentation

laminr status

Description

Overview of the current status of the laminr package and its dependencies. Can be useful for debugging.

Usage

laminr_status()

Details

Provides information that can be useful for debugging. To run the function when an error occurs, set ⁠options(error = function() { print(laminr::laminr_status() })⁠. Note that this should be used with some caution as it will print the status whenever any error occurs.

Value

A laminr_status object

Examples

laminr_status()

laminr documentation built on March 13, 2026, 5:08 p.m.