| laminr_status | R Documentation |
Overview of the current status of the laminr package and its dependencies. Can be useful for debugging.
laminr_status()
Provides information that can be useful for debugging. To run the function
when an error occurs, set
options(error = function() { print(laminr::laminr_status() }). Note that
this should be used with some caution as it will print the status whenever
any error occurs.
A laminr_status object
laminr_status()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.